==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/currentlinewidget.h <==
#ifndef CURRENTLINEWIDGET_H
#define CURRENTLINEWIDGET_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <subtitleline.h>
#include <textedit.h>

#include <qwidget.h>

class QTimer;
class QGridLayout;
class QLabel;
class TimeEdit;
class TextEdit;

namespace SubtitleComposer
{
	class CurrentLineWidget : public QWidget
	{
		Q_OBJECT

		public:

			CurrentLineWidget( QWidget* parent );
			virtual ~CurrentLineWidget();

			void loadConfig();
			void saveConfig();

		public slots:

			void setSubtitle( Subtitle* subtitle=0 );
			void setCurrentLine( SubtitleLine* line );

			void setTranslationMode( bool enabled );

			void highlightPrimary( int startIndex, int endIndex );
			void highlightSecondary( int startIndex, int endIndex );

		protected slots:

			void onPrimaryTextEditChanged();
			void onSecondaryTextEditChanged();
			void onShowTimeEditChanged( int showTime );
			void onHideTimeEditChanged( int hideTime );
			void onDurationTimeEditChanged( int durationTime );

			void onLinePrimaryTextChanged( const QString& primaryText );
			void onLineSecondaryTextChanged( const QString& secondaryText );
			void onLineShowTimeChanged( const Time& showTime );
			void onLineHideTimeChanged( const Time& hideTime );
			void onLineStyleFlagsChanged( int styleFlags );

		private:

			QString buildTextDescription( const QString& text );

		protected:

			SubtitleLine* m_currentLine;
			bool m_translationMode;

			bool m_updateCurrentLine;
			bool m_updateControls;

			QLabel* m_primaryTextLabel;
			TextEdit* m_primaryTextEdit;
			QLabel* m_secondaryTextLabel;
			TextEdit* m_secondaryTextEdit;
			TimeEdit* m_showTimeEdit;
			TimeEdit* m_hideTimeEdit;
			TimeEdit* m_durationTimeEdit;

			QGridLayout* m_mainLayout;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/main/currentlinewidget.h <==
#ifndef CURRENTLINEWIDGET_H
#define CURRENTLINEWIDGET_H

/***************************************************************************
*   Copyright (C) 2007-2008 by Sergio Pistone                             *
*   sergio_pistone@yahoo.com.ar                                           *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <subtitleline.h>
#include <simplerichtextedit.h>

#include <qwidget.h>

class QTimer;
class QGridLayout;
class QLabel;
class QToolButton;
class TimeEdit;
class SimpleRichTextEdit;

namespace SubtitleComposer
{
	class CurrentLineWidget : public QWidget
	{
		Q_OBJECT

		public:

			CurrentLineWidget( QWidget* parent );
			virtual ~CurrentLineWidget();

			bool hasFocus() const;

			void loadConfig();
			void saveConfig();

		public slots:

			void setSubtitle( Subtitle* subtitle=0 );
			void setCurrentLine( SubtitleLine* line );

			void setTranslationMode( bool enabled );

			void highlightPrimary( int startIndex, int endIndex );
			void highlightSecondary( int startIndex, int endIndex );

		signals:

			void focusChanged( bool hasFocus );

		protected slots:

// 			void toggleSelectionLowerCase();
// 			void toggleSelectionUpperCase();
// 			void toggleSelectionTitleCase();
// 			void toggleSelectionSentenceCase();

			void onPrimaryTextEditSelectionChanged();
			void onSecondaryTextEditSelectionChanged();

			void onPrimaryTextEditChanged();
			void onSecondaryTextEditChanged();
			void onShowTimeEditChanged( int showTime );
			void onHideTimeEditChanged( int hideTime );
			void onDurationTimeEditChanged( int durationTime );

			void onLinePrimaryTextChanged( const SString& primaryText );
			void onLineSecondaryTextChanged( const SString& secondaryText );
			void onLineShowTimeChanged( const Time& showTime );
			void onLineHideTimeChanged( const Time& hideTime );

			void onFocusChanged();

		protected:

			QToolButton* createToolButton( const QString& text, const char* icon, QObject* receiver, const char* slot );

			QString buildTextDescription( const QString& text );

			virtual void focusInEvent( QFocusEvent* event );
			virtual void focusOutEvent( QFocusEvent* event );

		protected:

			SubtitleLine* m_currentLine;
			bool m_translationMode;
			bool m_hasFocus;

			bool m_updateCurrentLine;
			bool m_updateControls;

			TimeEdit* m_showTimeEdit;
			TimeEdit* m_hideTimeEdit;
			TimeEdit* m_durationTimeEdit;

			QLabel* m_primaryTextLabel;
			SimpleRichTextEdit* m_primaryTextEdit;
			QToolButton* m_primaryItalicButton;
			QToolButton* m_primaryBoldButton;
			QToolButton* m_primaryUnderlineButton;
			QToolButton* m_primaryStrikeThroughButton;

			QLabel* m_secondaryTextLabel;
			SimpleRichTextEdit* m_secondaryTextEdit;
			QToolButton* m_secondaryItalicButton;
			QToolButton* m_secondaryBoldButton;
			QToolButton* m_secondaryUnderlineButton;
			QToolButton* m_secondaryStrikeThroughButton;

			QGridLayout* m_mainLayout;
	};
}

#endif
